Learn R Programming

origami (version 0.8.0)

Combiners: Combiners

Description

Combiners are functions that collapse across a list of similarly structured results. These are standard idioms for combining lists of certain data types.

Usage

combiner_rbind(x)

combiner_c(x)

combiner_factor(x)

combiner_array(x)

Arguments

x

(list) - a list of similar results to be combined.

Value

A combined results object.