guess_combiner: Flexible Guessing and Mapping for Combining Data Types

View source: R/combine_results.R

guess_combinerR Documentation

Flexible Guessing and Mapping for Combining Data Types

Description

Maps data types into standard combiners that should be sensible.

Usage

guess_combiner(result)

Arguments

result

A single result; flexibly accepts several object classes.

Value

A function to combine a list of such results.


origami documentation built on May 18, 2026, 9:07 a.m.