Learn R Programming

origami (version 0.8.0)

guess_combiner: Flexible Guessing and Mapping for Combining Data Types

Description

Maps data types into standard combiners that should be sensible.

Usage

guess_combiner(result)

Arguments

result

- a single result; flexibly accepts several object classes.

Value

A function to combine a list of such results.