powered by
Maps data types into standard combiners that should be sensible.
guess_combiner(result)
- a single result; flexibly accepts several object classes.
A function to combine a list of such results.